@@ -15,7 +15,7 @@ with ignoring(ImportError):
 
 
 def resource_profile_plot(width=600, height=300):
-    names = ['time', 'cpu', 'memory-percent', 'network-send']
+    names = ['time', 'cpu', 'memory-percent', 'network-send', 'network-recv']
     source = ColumnDataSource({k: [] for k in names})
 
     x_range = DataRange1d(follow='end', follow_interval=30000, range_padding=0)
@@ -24,20 +24,24 @@ def resource_profile_plot(width=600, height=300):
                responsive=True, tools='xpan,xwheel_zoom,box_zoom,resize,reset',
                x_range=x_range, y_range=y_range)
     p.line(x='time', y='memory-percent', line_width=2, line_alpha=0.8,
-           color=Spectral9[7], legend='Avg Memory Usage', source=source)
+           color=Spectral9[7], legend='Memory', source=source)
     p.line(x='time', y='cpu', line_width=2, line_alpha=0.8,
-           color=Spectral9[0], legend='Avg CPU Usage', source=source)
+           color=Spectral9[0], legend='CPU', source=source)
     p.legend[0].location = 'top_left'
     p.yaxis[0].formatter = NumeralTickFormatter(format="0 %")
     p.min_border_right = 10
-    p.extra_y_ranges = {"send": DataRange1d(bounds=(0, None))}
-    p.add_layout(LinearAxis(y_range_name="send", axis_label="Throughput (MB/s)"),
+    p.extra_y_ranges = {"network": DataRange1d(bounds=(0, None))}
+    p.add_layout(LinearAxis(y_range_name="network",
+                            axis_label="Throughput (MB/s)"),
                  'right')
     p.yaxis.axis_label_text_font_size = "10pt"
 
     p.line(x='time', y='network-send', line_width=2, line_alpha=0.8,
-           color=Spectral9[2], legend='Network', source=source,
-           y_range_name="send")
+           color=Spectral9[2], legend='Network Send', source=source,
+           y_range_name="network")
+    p.line(x='time', y='network-recv', line_width=2, line_alpha=0.8,
+           color=Spectral9[3], legend='Network Recv', source=source,
+           y_range_name="network")
 
     return source, p
 
@@ -47,7 +51,7 @@ def resource_profile_update(source, worker_buffer, times_buffer):
 
     workers = sorted(list(set(chain(*list(w.keys() for w in worker_buffer)))))
 
-    for name in ['cpu', 'memory-percent', 'network-send']:
+    for name in ['cpu', 'memory-percent', 'network-send', 'network-recv']:
         data[name] = [[msg[w][name] if w in msg and name in msg[w] else 'null'
                        for msg in worker_buffer]
                        for w in workers]
@@ -68,13 +72,15 @@ def resource_append(lists, msg):
         lists[k].append(mean(pluck(k, L)) / 100)
 
     lists['time'].append(mean(pluck('time', L)) * 1000)
-    net = mean(pluck('network-send', L, 0))
     if len(lists['time']) >= 2:
         t1, t2 = lists['time'][-2], lists['time'][-1]
         interval = (t2 - t1) / 1000
     else:
         interval = 0.5
-    lists['network-send'].append(net / 2**20 / (interval or 0.5))
+    send = mean(pluck('network-send', L, 0))
+    lists['network-send'].append(send / 2**20 / (interval or 0.5))
+    recv = mean(pluck('network-recv', L, 0))
+    lists['network-recv'].append(recv / 2**20 / (interval or 0.5))
 
 
 def mean(seq):
